@@ -78,18 +78,26 @@
 *     / LOOP FOR EACH PIXEL /
 
         CALL SGQTXY(TXM,TXX,TYM,TYX)
- 362    IF (TXM.LT.-180.) TXM=TXM+360.
-        IF (TXM.GT.180.) TXM=TXM-360.
-        IF ((TXM.LT.-180.).OR.(TXM.GT.180.)) GOTO 362
- 363    IF (TXX.LT.-180.) TXX=TXX+360.
-        IF (TXX.GT.180.) TXX=TXX-360.
-        IF ((TXX.LT.180.).OR.(TXX.GT.180.)) GOTO 363
- 365    IF (TYM.LT.-90.) TYM=TYM+180.
-        IF (TYM.GT.90.) TYM=TYM-180.
-        IF ((TYM.LT.-90.).OR.(TYM.GT.90.)) GOTO 365
- 366    IF (TYX.LT.-90.) TYX=TYX+180.
-        IF (TYX.GT.90.) TYX=TYX-180.
-        IF ((TYX.LT.-90.).OR.(TYX.GT.90.)) GOTO 366
+        IF (TXM.NE.RUNDEF)THEN
+   362    IF (TXM.LT.-180.) TXM=TXM+360.
+          IF (TXM.GT.180.) TXM=TXM-360.
+          IF ((TXM.LT.-180.).OR.(TXM.GT.180.)) GOTO 362
+        END IF
+        IF (TXX.NE.RUNDEF)THEN
+   363    IF (TXX.LT.-180.) TXX=TXX+360.
+          IF (TXX.GT.180.) TXX=TXX-360.
+          IF ((TXX.LT.-180.).OR.(TXX.GT.180.)) GOTO 363
+        END IF
+        IF (TYM.NE.RUNDEF)THEN
+   365    IF (TYM.LT.-90.) TYM=TYM+180.
+          IF (TYM.GT.90.) TYM=TYM-180.
+          IF ((TYM.LT.-90.).OR.(TYM.GT.90.)) GOTO 365
+        END IF
+        IF (TYX.NE.RUNDEF)THEN
+   366    IF (TYX.LT.-90.) TYX=TYX+180.
+          IF (TYX.GT.90.) TYX=TYX-180.
+          IF ((TYX.LT.-90.).OR.(TYX.GT.90.)) GOTO 366
+        END IF
 
       DO 30 J=1, IHIGHT
 
